#
# spec file for package nautilus-share
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         nautilus_extdir %(pkg-config --variable=extensiondir libnautilus-extension-4)
Name:           nautilus-share
Version:        0.7.5
Release:        3.3
Summary:        Nautilus plugin for sharing directories over SMB
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Samba
URL:            https://git.gnome.org/nautilus-share
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM nautilus-share-lang-fix.patch -- Add LINGUAS file to po dir
Patch0:         nautilus-share-lang-fix.patch
# PATCH-FIX-UPSTREAM 5.patch dmulder@suse.com bsc#1208375 -- 'Everyone' represented by WKS 'World' S-1-1-0
Patch2:         https://gitlab.gnome.org/coreyberla/nautilus-share/-/merge_requests/5.patch

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.4.0
BuildRequires:  pkgconfig(gtk4) >= 4.6.0
BuildRequires:  pkgconfig(libnautilus-extension-4) >= 43.rc
Requires:       samba-client >= 3.0.23

%description
An application for the GNOME desktop integrated into Nautilus
which allows use of Nautilus shares without signing in as root.

Features:

* A new command in the Nautilus context menu
  (Menu key or right click).

* A dialog to share a directory, which allows choosing a
  name and decide on read-only/read-write status.

* Possibility to access the share settings from the Properties
  tab of a directory.

* Possibility to examine whether a share name already exists by
  typing it.

* Nautilus displays a palm icon to visually show which
  directories are shared.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license COPYING
%doc AUTHORS README
%{nautilus_extdir}/libnautilus-share.so
%dir %{_datadir}/interfaces
%{_datadir}/interfaces/share-dialog-gtk4.ui
%{_datadir}/interfaces/share-dialog.ui

%files lang -f %{name}.lang

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Feb 16 2023 David Mulder <dmulder@suse.com>
- Add 5.patch: Fix `'net usershare' returned error 255`
  (bsc#1208375).
* Wed Sep 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.7.5:
  + Fix dialogs for permission changes
  + Fix misc issues
- Changes from version 0.7.4:
  + Port to libnautilus-extension-4 for Nautilus 43 compatibility
  + Port to GTK4
  + Port from autotools to Meson
  + Fix misc issues
- Switch to source service.
- Add meson BuildRequires and macros following upstreams port.
- Other changes in BuildRequires:
  + Added: pkgconfig, pkgconfig(glib-2.0), pkgconfig(gtk4) and
    pkgconfig(libnautilus-extension-4)
  + Dropped: intltool, nautilus-devel and libtool.
- Add nautilus-share-lang-fix.patch: Add LINGUAS file to po dir
  https://gitlab.gnome.org/coreyberla/nautilus-share/-/issues/2
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Thu Mar  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Require samba-client instead of samba: we need /usr/bin/net,
  which is a client tool (identified as part of boo#1183047).
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Apr 30 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Thu Apr 26 2018 badshah400@gmail.com
- Drop Requires: gnome-icon-theme; the appropriate icon is
  provided by adwaita-icon-theme (pulled in by gtk3) already.
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Jul  9 2011 vuntz@opensuse.org
- Update to version 0.7.3:
  + See previous entry for the list of changes; there is no new
    change.
- Drop nautilus-share-git20110615-6c0fa271.patch: part of upstream.
* Wed Jun 15 2011 vuntz@opensuse.org
- Add nautilus-share-git20110615-6c0fa271.patch. This is a patch
  adding all changes to git from 0.7.2 to today (6c0fa271). This
  contains the following changes:
  + Allow actions to be undone without closing window
  + Do not always require go+rx permissions
  + Set the title of the sharing options window
  + Standardize wording for writable option
  + Change location of Comment field
  + Use folder-remote icon
  + Fix validation of false positives
  + Fix false negative in detecting writable option
  + Don't print status messages in session log
  + Remove usage of deprecated libraries (libgnomeui, gnome-vfs,
    eel, libglade)
  + Build fixes.
- Drop nautilus-share-drop-eel.patch and
  nautilus-share-bnc358451-extension-dir.patch: they are included
  in the patch.
- Drop nautilus-share-po.tar.gz: translation-update-upstream does
  the work of updating translations already.
- Remove unneeded BuildRequires: fdupes, gnome-patch-translation,
  libglade2-devel, update-desktop-files.
- Fix build against GNOME 3, by packaging the file in the right
  directory (which is versioned). We use pkg-config to find this
  directory now, instead of manually defining it.
- Update Url tag to git.gnome.org, since the old website is down.
- Use spec-cleaner to cleanup spec file.
* Sun Feb 27 2011 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Jan 30 2009 vuntz@novell.com
- Add nautilus-share-drop-eel.patch to let us drop eel and
  gnome-vfs dependecies.
- Adjust BuildRequires.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translation update
* Thu Apr  3 2008 hpj@suse.de
- Upgraded to version 0.7.2.
- Removed upstreamed patches:
  * nautilus-share-183413-restore-write-permissions.diff
  * nautilus-share-181811-guest-permissions.diff
  * nautilus-share-170212-restore-modified-permissions.diff
  * nautilus-share-potfiles.patch
  * nautilus-share-new-potfiles.patch
* Tue Mar 11 2008 maw@suse.de
- Fix build: nautilus modules now go in
  %%{_libdir}/nautilus/extension-2.0.
* Tue Mar  4 2008 federico@novell.com
- Added nautilus-share-bnc358451-extension-dir.patch to fix the
  nautilus-share part of
  https://bugzilla.novell.com/show_bug.cgi?id=358451 - fix the
  directory in which Nautilus extensions get installed.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Wed Jan 17 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
* Tue Sep 26 2006 jhargadon@suse.de
- update to version 0.7.0
- Remove the requirements for d-bus and libdaemon
- Remove the smbshared entries; we only need the extension's .so now
* Mon Jun 26 2006 sbrabec@suse.cz
- Added missing file to POTFILES.in (#183392).
* Thu Jun 15 2006 federico@novell.com
- Added nautilus-share-183413-restore-write-permissions.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=183413.  This makes
  nautilus-share remove the write permissions from a usershared folder
  as soon as possible, when the share is modified to be read-only.
* Fri Jun  9 2006 federico@novell.com
- Added nautilus-share-181811-guest-permissions.diff to fix bug
  https://bugzilla.novell.com/show_bug.cgi?id=181811.  This will add
  the "guest_ok=y" option to the "net usershare" command line, as well
  as adding group permissions to the shared folder if appropriate.
* Wed May  3 2006 federico@novell.com
- Added nautilus-share-170212-restore-modified-permissions.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=170212.  We now restore
  the permissions of a folder when unsharing it.
* Wed Feb 22 2006 federico@novell.com
- Updated nautilus-share-net-usershare.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=152552.  Now we don't
  change the folder's permissions unconditionally; instead, we ask the
  user first.
- Do not install all the obsolete d-bus and smbshared parts; nautilus-share
  now requires just the .so extension and its data files.
* Tue Feb 21 2006 sbrabec@suse.cz
- Do not restart dbus on update (#152554).
* Mon Feb 20 2006 federico@novell.com
- Updated nautilus-share-net-usershare.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=149615; nautilus-share
  will now automatically change the permissions of the shared folder
  if they are not enough for sharing.
* Mon Feb  6 2006 federico@novell.com
- Updated nautilus-share-net-usershare.diff to fix the crash in
  https://bugzilla.novell.com/show_bug.cgi?id=147065.
* Wed Feb  1 2006 sbrabec@suse.cz
- Fixed POTFILES.
- Use translation compendium gnome-patch-translation.
* Fri Jan 27 2006 federico@novell.com
- Fix error reporting so that if Samba's "net usershare" is misconfigured,
  nautilus-share will be able to tell you about it.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 federico@novell.com
- Added nautilus-share-net-usershare.diff.  This makes nautilus-share
  use the new "net usershare" command from Samba instead of a
  home-grown scheme for sharing a user's personal files.  This
  requires samba-3.0.21a-4.2 or later.
- Added a build dependency on intltool.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Fri Sep 23 2005 sbrabec@suse.cz
- New SuSE package, version 0.6.4.
